util

package
v0.0.0-...-67a34a8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2019 License: MIT Imports: 5 Imported by: 3

Documentation

Overview

Package util contains supplimentary functionality like logging

Index

Constants

const (
	LogDebug   = "LOG_DEBUG"
	LogInfo    = "LOG_INFO"
	LogWarning = "LOG_WARNING"
	LogError   = "LOG_ERROR"
)

Identifies expected values the environment variable "LOG_LEVEL" can be

Variables

var TypeLogger = newTypeLogger()

TypeLogger is a wrapper for log that exposes priority based logging functions

Functions

func SetLogFile

func SetLogFile(filepath string) bool

SetLogFile tries to set a file printout should be sent to returning true or false based on whether it was successfull or not

func SetLogLevel

func SetLogLevel(level string) bool

SetLogLevel sets the minimal priority a requiered for printout

Types

This section is empty.

Jump to