Documentation
¶
Overview ¶
Package util contains supplimentary functionality like logging
Index ¶
Constants ¶
const ( LogDebug = "LOG_DEBUG" LogInfo = "LOG_INFO" LogWarning = "LOG_WARNING" LogError = "LOG_ERROR" )
Identifies expected values the environment variable "LOG_LEVEL" can be
Variables ¶
var TypeLogger = newTypeLogger()
TypeLogger is a wrapper for log that exposes priority based logging functions
Functions ¶
func SetLogFile ¶
SetLogFile tries to set a file printout should be sent to returning true or false based on whether it was successfull or not
func SetLogLevel ¶
SetLogLevel sets the minimal priority a requiered for printout
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.